@@ -29,10 +29,14 @@ class MindsDBParser(Parser):
     tokens = MindsDBLexer.tokens
 
     precedence = (
-        ('left', PLUS, MINUS, OR),
-        ('left', STAR, DIVIDE, AND),
-        ('right', UMINUS, UNOT),  # Unary minus operator, unary not
-        ('nonassoc', LESS, LEQ, GREATER, GEQ, EQUALS, NEQUALS, IN, BETWEEN, IS, IS_NOT, LIKE),
+        ('left', OR),
+        ('left', AND),
+        ('right', UNOT),
+        ('left', EQUALS, NEQUALS),
+        ('left', PLUS, MINUS),
+        ('left', STAR, DIVIDE),
+        ('right', UMINUS),  # Unary minus operator, unary not
+        ('nonassoc', LESS, LEQ, GREATER, GEQ, IN, BETWEEN, IS, IS_NOT, LIKE),
     )
 
     # Top-level statements
@@ -810,6 +814,8 @@ class MindsDBParser(Parser):
        'FULL JOIN',
        'CROSS JOIN',
        'OUTER JOIN',
+       'LEFT OUTER JOIN',
+       'FULL OUTER JOIN',
        )
     def join_clause(self, p):
         return ' '.join([x for x in p])
@@ -935,8 +941,12 @@ class MindsDBParser(Parser):
         return Function(op=p.id, distinct=True, args=p.expr_list)
 
     @_('id LPAREN expr_list_or_nothing RPAREN')
+    @_('id LPAREN star RPAREN')
     def function(self, p):
-        args = p.expr_list_or_nothing
+        if hasattr(p, 'star'):
+            args = [p.star]
+        else:
+            args = p.expr_list_or_nothing
         if not args:
             args = []
         return Function(op=p.id, args=args)
@@ -1072,12 +1082,8 @@ class MindsDBParser(Parser):
         params.update(p.kw_parameter)
         return params
 
-    @_('identifier EQUALS string')
-    @_('identifier EQUALS integer')
-    @_('identifier EQUALS float')
     @_('identifier EQUALS object')
-    @_('identifier EQUALS json')
-    @_('identifier EQUALS json_array_list')
+    @_('identifier EQUALS json_value')
     def kw_parameter(self, p):
         key = '.'.join(p.identifier.parts)
         return {key: p[2]}
